package com.gic.qywx.self;

import java.io.*;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpServletRequest;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.io.IOUtils;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.mime.content.ByteArrayBody;
import org.apache.http.entity.mime.content.ContentBody;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;

@RestController
@RequestMapping("/qywx")
public class QywxController {

    private Logger logger = LogManager.getLogger(QywxController.class);


    @RequestMapping("self-post")
    public Object selfPost(String url, String json, String ip) {
        logger.info("自建post,url={},json={},ip={}", url, json,ip);
        Map<String, Object> map = HttpClient.getWinxinResByJson(url, json, getIp(ip) , ip);
        return map;
    }

    @RequestMapping("self-post-json")
    public Object selfPostJson(String url, @RequestBody Map<String, Object> jsonBody, String ip) {
        String json = null ;
        if(null != jsonBody) {
            json = JSONObject.toJSONString(jsonBody) ;
        }
        logger.info("自建post-json,url={},json={},,ip={}", url, json,ip);
        Map<String, Object> map = HttpClient.getWinxinResByJson(url, json, getIp(ip) , ip);
        return map;
    }

    @RequestMapping("self-post-json-body")
    public Object selfPostJson(HttpServletRequest request, String url,  String ip) throws IOException {
        InputStream inputStream = request.getInputStream();
        Map<String, Object> map = null ;
        try {
            String json = IOUtils.toString(inputStream,"UTF-8") ;
            logger.info("自建post-json,url={},json={},ip={}", url, json,ip);
            map = HttpClient.getWinxinResByJson(url, json, getIp(ip) , ip);
        }finally {
            IOUtils.closeQuietly(inputStream);
        }
        return map;
    }

    @RequestMapping("self-get")
    public Object selfGet(HttpServletRequest request,String url, String ip) {
        logger.info("自建get,url={},ip={}", url,ip);
        Map<String, Object> map = HttpClient.getHttpByGet(url, getIp(ip) , ip);
        return map;
    }

    @RequestMapping("self-upload")
    public Object selfUpload(String url, String fileUrl, String fileName, String ip) {
        logger.info("自建upload,url={},fileUrl={},ip={}", url,fileUrl,ip);
        byte[] data = CommonUtil.getFileByte(fileUrl);
        Map<String, ContentBody> paramsMap = new HashMap<String, ContentBody>();
        paramsMap.put("media", new ByteArrayBody(data, ContentType.DEFAULT_BINARY, fileName));
        Map<String, Object> map = HttpClient.getWinxinResByFile(url, paramsMap, getIp(ip) , ip);
        return map;
    }

    @RequestMapping("self-upload-data")
    public Object selfImage(HttpServletRequest request,String url, String fileName,  String ip) throws IOException {
        logger.info("自建upload-data,url={},ip={}", url,ip);
        MultipartHttpServletRequest multiRequest = (MultipartHttpServletRequest) request;
        List<MultipartFile> list = multiRequest.getMultiFileMap().get("media");
        MultipartFile mf = list.get(0);
        byte[] data = mf.getBytes();
        Map<String, ContentBody> paramsMap = new HashMap<String, ContentBody>();
        paramsMap.put("media", new ByteArrayBody(data, ContentType.DEFAULT_BINARY, fileName));
        Map<String, Object> map = HttpClient.getWinxinResByFile(url, paramsMap, getIp(ip) , ip);
        return map;
    }
    
    // 必须是内网ip
    private byte[] getIp(String ip) {
        if(StringUtils.isEmpty(ip)) {
            return null ;
        }
        String[] arr = ip.split("\\.");
        byte[] b = new byte[] {Integer.valueOf(arr[0]).byteValue(),  Integer.valueOf(arr[1]).byteValue(),Integer.valueOf(arr[2]).byteValue(),Integer.valueOf(arr[3]).byteValue()};
        return b;
    }
}
